import json
import os
import httplib2
import config

USER_AGENT = 'HeyWatch/2.2.0 (Python)'

def submit(config_content, **kwargs):
  heywatch_url = os.getenv('HEYWATCH_URL', 'https://heywatch.com')
  api_key = os.getenv('HEYWATCH_API_KEY')

  if 'api_key' in kwargs:
    api_key = kwargs['api_key']

  h = httplib2.Http()
  h.add_credentials(api_key, '')

  headers = {'User-Agent': USER_AGENT, 'Content-Type': 'text/plain', 'Accept': 'application/json'}

  response, content = h.request(heywatch_url + '/api/v1/job', 'POST', body=config_content, headers=headers)

  return json.loads(content.decode('utf-8'))

def create(**kwargs):
  return submit(config.new(**kwargs), **kwargs)



def new(**kwargs):
  if 'conf' in kwargs:
    conf_file = kwargs['conf']
    conf = open(conf_file).read().strip().splitlines()
  else:
    conf = []

  if 'vars' in kwargs:
    vars = kwargs['vars']
    for name,value in vars.items():
      conf.append('var ' + name + ' = ' + str(value))

  if 'source' in kwargs:
    source = kwargs['source']
    conf.append('set source = ' + source)

  if 'webhook' in kwargs:
    webhook = kwargs['webhook']
    conf.append('set webhook = ' + webhook)

  if 'outputs' in kwargs:
    outputs = kwargs['outputs']
    for format,cdn in outputs.items():
      conf.append('-> ' + format + ' = ' + cdn)

  new_conf = []
  new_conf += sorted(filter(lambda l: l.startswith('var'), conf))
  new_conf.append('')
  new_conf += sorted(filter(lambda l: l.startswith('set'), conf))
  new_conf.append('')
  new_conf += sorted(filter(lambda l: l.startswith('->'), conf))

  return "\n".join(new_conf)


from setuptools import setup, find_packages
import sys, os

def read(*paths):
    """Build a file path from *paths* and return the contents."""
    with open(os.path.join(*paths), 'r') as f:
        return f.read()
setup(
  name = 'heywatch',
  version = '2.2.0',
  py_modules = ['heywatch.job', 'heywatch.config'],
  packages=find_packages(exclude=['tests*']),
  author='Bruno Celeste',
  author_email='bruno@heywatch.com',
  description='A python wrapper around the HeyWatch API',
  license='MIT License',
  url='http://www.heywatchencoding.com',
  keywords='heywatch api',
  long_description="""Client Library for encoding Videos with HeyWatch

HeyWatch is a Video Encoding Web Service.

For a CLI, look at the ruby version: http://github.com/particles/heywatch-ruby

For more information:

* HeyWatch: http://www.heywatchencoding.com
* API Documentation: http://www.heywatchencoding.com/docs
* Twitter: @heywatch / @sadikzzz

Changelogs

2.2.0
Added a new method #config to generate a full configuration based on the given parameters. It's especially useful to handle dynamic settings like source or variables that can be set directly in code.

2.0.0
New version of the client library which uses the HeyWatch API v2. This library is not compatible with 1.x

1.0.0
First version

"""
)